<?php
/**
 * Simple Gallery action interface
 *
 * $Id: Abstract.php 203 2011-02-18 17:46:16Z indy $
 *
 * $LastChangedBy: indy $
 *
 * $LastChangedDate: 2011-02-18 19:46:16 +0200 (Fri, 18 Feb 2011) $
 *
 * $Rev: 203 $
 *
 * @author Indiana Jones <indy2kro@yahoo.com>
 * @package SimpleGallery
 * @version 1.0
 * @copyright 2011 Simple Gallery
 */

/**
 * Simple Gallery action interface
 */
abstract class SimpleGallery_Action_Abstract
{
    /**
     * Action parameters
     * 
     * @var array
     */
    protected $_params = array();

    /**
     * Current path
     *
     * @var string
     */
    protected $_path;

    /**
     * Main run method
     *
     * @param array $params The action parameters
     * @return void
     */
    public function run(Array $params = array())
    {
        $this->_params = $params;

        // set path
        $this->_setPath();
    }

    /**
     * Set path from params
     *
     * @return void
     */
    protected function _setPath()
    {
        if (!isset($this->_params['path'])) {
            return null;
        }

        $path = $this->_params['path'];

        $path = rtrim($path, '/')  . '/';
        $path = ltrim($path, '/.');

        $this->_path = $this->_cleanDirectoryPath($path);
    }

    /**
     * Clean directory path
     *
     * @param string $path The directory path
     * @return string
     */
    protected function _cleanDirectoryPath($path)
    {
        $path = rtrim($path, '/') . '/';

        return $path;
    }

    /**
     * Display footer
     *
     * @return void
     */
    protected function _displayFooter()
    {
        echo '
<div id="simplegallery-copyright">Powered by <a href="http://php.bubble.ro/simplegallery/">SimpleGallery</a></div>

</div>
</body>
</html>';
    }

    /**
     * Get title from file name
     *
     * @param string $name The name to get the formatted title for
     * @return string The formatted title
     */
    protected function _getTitle($name)
    {
        $name = basename($name);

        // get last position of dot
        $pos = strrpos($name, '.');

        // name does not contain dot, return the entire name
        if (false === $pos) {
            return $name;
        }

        // get the first part of the file name
        $title = substr($name, 0, $pos);

        return $title;
    }
}

/* EOF */