<?php
/**
 * Simple Gallery create thumbnail action
 *
 * $Id: Thumb.php 203 2011-02-18 17:46:16Z indy $
 *
 * $LastChangedBy: indy $
 *
 * $LastChangedDate: 2011-02-18 19:46:16 +0200 (Fri, 18 Feb 2011) $
 *
 * $Rev: 203 $
 *
 * @author Indiana Jones <indy2kro@yahoo.com>
 * @package SimpleGallery
 * @version 1.0
 * @copyright 2011 Simple Gallery
 */

/**
 * Simple Gallery create thumbnail action
 */
class SimpleGallery_Action_Thumb extends SimpleGallery_Action_Abstract
{
    /**
     * Image name
     * 
     * @var string
     */
    protected $_image;

    /**
     * Main run method
     * 
     * @param array $params Action parameters
     * @return void
     */
    public function run(Array $params = array())
    {
        parent::run($params);

        $config = SimpleGallery_Registry::get('config');

        $this->_image = $params['thumb'];

        $fullPath = $this->_cleanDirectoryPath($config['source_directory']) . $this->_path;
        $fullPath = $this->_cleanDirectoryPath($fullPath);

        $filePath = $fullPath . $this->_image;
        $thumbPath = $fullPath . $config['thumbnail_directory'] . '/' . $this->_image;

        try {
            $this->_createThumbnail($filePath, $thumbPath);
        } catch (Exception $ex) {
            // failed to create image, display 404
            header('HTTP/1.0 404 Not Found');
            echo $ex->getMessage();
            exit;
        }

        $thumbPublicPath = $config['public_url'] . '/' . $this->_path . $config['thumbnail_directory'] . '/' . $this->_image;

        // reload image
        header('Location: ' . $thumbPublicPath . '?reload');
        exit;
    }

    /**
     * Check if the image thumbnail exists. If it doesn't exist, create it
     *
     * @param string $filePath Source file path
     * @param string $thumbPath Thumbnail file path
     * @throws SimpleGallery_Exception
     * @return boolean
     */
    protected function _createThumbnail($filePath, $thumbPath)
    {
        $config = SimpleGallery_Registry::get('config');

        if (file_exists($thumbPath)) {
            return true;
        }

        $thumbDir = dirname($thumbPath);

        if (!is_dir($thumbDir)) {
            mkdir($thumbDir);
        }

        $options = array(
            SimpleGallery_Image::OPTION_HEIGHT => $config['thumbnail_height'],
            SimpleGallery_Image::OPTION_WIDTH => $config['thumbnail_width']
        );

        try {
            $image = new SimpleGallery_Image();
            $image->thumbnail($filePath, $thumbPath, $options);
        } catch (SimpleGallery_Exception $ex) {
            throw new SimpleGallery_Exception('Failed to create thumbnail for ' . $filePath . ' - ' . $ex->getMessage());
        }
    }
}

/* EOF */