<?php
/**
 * Bootstrap file
 *
 * $Id: Bootstrap.php 203 2011-02-18 17:46:16Z indy $
 *
 * $LastChangedBy: indy $
 *
 * $LastChangedDate: 2011-02-18 19:46:16 +0200 (Fri, 18 Feb 2011) $
 *
 * $Rev: 203 $
 *
 * @author Indiana Jones <indy2kro@yahoo.com>
 * @package SimpleGallery
 * @version 1.0
 * @copyright 2011 Simple Gallery
 */

/**
 * Simple Gallery bootstrap file
 */
class SimpleGallery_Bootstrap
{
    /**
     * Constructor
     *
     * @param array $config Configuration parameters
     * @return void
     */
    public function __construct(Array $config = array())
    {
        // set include path
        $this->_setIncludePath();

        // init class auto loader
        $this->_initAutoLoader();

        // set config values
        $config['public_url'] = rtrim($config['public_url'], '/');

        SimpleGallery_Registry::set('config', $config);
    }
    
    /**
     * Main run method
     *
     * @return void
     */
    public function run()
    {
        // default action is browse
        $action = SimpleGallery_Router::ACTION_BROWSE;

        // set action
        if (isset($_GET['action'])) {
            $action = $_GET['action'];
        }

        try {
            // route action
            $router = new SimpleGallery_Router();
            $router->route($action, $_GET);
        } catch (Exception $ex) {
            $params = array(
                'message' => $ex->getMessage()
            );

            $action404 = new SimpleGallery_Action_404();
            $action404->run($params);
        }
    }

    /**
     * Set include path
     *
     * @return void
     */
    protected function _setIncludePath()
    {
        $path = dirname(dirname(__FILE__)) . '/';
        set_include_path(get_include_path() . PATH_SEPARATOR . $path);
    }

    /**
     * Init the auto loader
     *
     * @return void
     */
    protected function _initAutoLoader()
    {
        require_once(dirname(__FILE__) . '/AutoLoader.php');

        $autoLoader = new SimpleGallery_AutoLoader();
        $autoLoader->register();
    }
}

/* EOF */