<?php
/**
 * Simple Gallery directory
 *
 * $Id: 404.php 191 2011-02-16 20:53:05Z indy $
 *
 * $LastChangedBy: indy $
 *
 * $LastChangedDate: 2011-02-16 22:53:05 +0200 (Wed, 16 Feb 2011) $
 *
 * $Rev: 191 $
 *
 * @author Indiana Jones <indy2kro@yahoo.com>
 * @package SimpleGallery
 * @version 1.0
 * @copyright 2011 Simple Gallery
 */

/**
 * Simple Gallery directory
 */
class SimpleGallery_Directory
{
    /**
     * Count images in a gallery
     *
     * @param string $galleryPath The image gallery path
     * @return array An array with the images from the directory
     */
    public function getImages($galleryPath)
    {
        $config = SimpleGallery_Registry::get('config');

        $galleryPath = rtrim($galleryPath, '/') . '/';

        $fileExtensions = explode(',', $config['file_extensions']);
        $fileExtensions = implode('|', $fileExtensions);

        $acceptedPattern = '/(' . $fileExtensions . ')$/i';

        $images = array();
        
        $path = $config['source_directory'] . '/' . $galleryPath;
        $relativePath =  $config['public_url'] . '/' . $galleryPath;

        $path = rtrim($path, '/') . '/';

        $dh = opendir($path);

        if (!$dh) {
            return $countImages;
        }

        while (($file = readdir($dh)) !== false) {

            // skip files that start with .
            if (preg_match('/^\./', $file)) {
                continue;
            }

            $filePath = $relativePath;
            
            $thumbPublicPath = $filePath . $config['thumbnail_directory'] . '/' . $file;

            $filePath .= $file;

            $fullPath = $path . $file;

            $fileItem = array(
                'name' => $file,
                'path' => $filePath,
                'thumbnail' => $thumbPublicPath,
                'title' => $this->_getTitle($file),
                'fullpath' => $fullPath
            );

            if (is_file($fullPath)) {
                if (!preg_match($acceptedPattern, $file)) {
                    continue;
                }

                $images[] = $fileItem;
            }
        }

        closedir($dh);

        return $images;
    }

    /**
     * Count images in a gallery
     *
     * @param string $path The absolute path for the gallery
     * @param string $relativePath The relative path for the gallery
     * @return integer Returns the number of images found
     */
    public function countImages($path, $relativePath)
    {
        $images = $this->getImages($path, $relativePath);
        $countImages = count($images);

        return $countImages;
    }

    /**
     * Get title from file name
     *
     * @param string $name The directory name
     * @return string Returns the title formatted properly
     */
    protected function _getTitle($name)
    {
        $name = basename($name);

        // get last position of dot
        $pos = strrpos($name, '.');

        // name does not contain dot, return the entire name
        if (false === $pos) {
            return $name;
        }

        // get the first part of the file name
        $title = substr($name, 0, $pos);

        return $title;
    }
}

/* EOF */