<?php
/**
 * Simple Gallery image file
 *
 * $Id: Image.php 203 2011-02-18 17:46:16Z indy $
 *
 * $LastChangedBy: indy $
 *
 * $LastChangedDate: 2011-02-18 19:46:16 +0200 (Fri, 18 Feb 2011) $
 *
 * $Rev: 203 $
 *
 * @author Indiana Jones <indy2kro@yahoo.com>
 * @package SimpleGallery
 * @version 1.0
 * @copyright 2011 Simple Gallery
 */

/**
 * Simple Gallery image
 */
class SimpleGallery_Image
{
    /**
     * Available options
     */

    /**
     * Option key for image width
     */
    const OPTION_WIDTH = 'simplegallery_width';

    /**
     * Option key for image height
     */
    const OPTION_HEIGHT = 'simplegallery_height';

    /**
     * Option key for output format
     */
    const OPTION_OUTPUT_FORMAT = 'simplegallery_output_format';

    /**
     * Thumbnailer object
     *
     * @var SimpleGallery_Thumb
     */
    protected $_thumbnailer;

    /**
     * Create a thumbnail
     *
     * @param string $sourcePath The file path for the source image
     * @param string $destinationPath Thefile path for the destination image
     * @param array $options Options for the method
     * @throws SimpleGallery_Exception
     * @return boolean
     */
    public function thumbnail($sourcePath, $destinationPath, Array $options)
    {
        // image width must be valid
        if (!isset($options[self::OPTION_WIDTH]) || !is_numeric($options[self::OPTION_WIDTH])) {
            throw new SimpleGallery_Exception('Image width must be greater than 0.');
        }

        // image height must be valid
        if (!isset($options[self::OPTION_HEIGHT]) || !is_numeric($options[self::OPTION_HEIGHT])) {
            throw new SimpleGallery_Exception('Image height must be greater than 0.');
        }

        try {
            // create thumbnailer object
            $this->_thumbnailer = new SimpleGallery_Thumb($sourcePath, $options);

            // generate thumbnail
            $this->_thumbnailer->adaptiveResize($options[self::OPTION_WIDTH], $options[self::OPTION_HEIGHT]);

            // save the thumbnail
            if (isset($options[self::OPTION_OUTPUT_FORMAT])) {
                $this->_thumbnailer->save($destinationPath, $options[self::OPTION_OUTPUT_FORMAT]);
            } else {
                $this->_thumbnailer->save($destinationPath);
            }
        } catch (Exception $ex) {
            throw new SimpleGallery_Exception('Failed to create thumbnail: ' . $ex->getMessage());
        }

        return true;
    }

    /**
     * Resize an image
     *
     * @param string $sourcePath The file path for the source image
     * @param string $destinationPath Thefile path for the destination image
     * @param array $options Options for the method
     * @throws SimpleGallery_Exception
     * @return mixed Returns true if the image was resized or NULL if resizing was not needed
     */
    public function resize($sourcePath, $destinationPath, Array $options)
    {
        // image width must be valid
        if (!isset($options[self::OPTION_WIDTH]) || !is_numeric($options[self::OPTION_WIDTH])) {
            throw new SimpleGallery_Exception('Image width must be greater than 0.');
        }

        // image height must be valid
        if (!isset($options[self::OPTION_HEIGHT]) || !is_numeric($options[self::OPTION_HEIGHT])) {
            throw new SimpleGallery_Exception('Image height must be greater than 0.');
        }

        try {
            // create thumbnailer object
            $this->_thumbnailer = new SimpleGallery_Thumb($sourcePath, $options);

            $width = $this->_thumbnailer->getWidth();
            $height = $this->_thumbnailer->getHeight();

            if ($width <= $options[self::OPTION_WIDTH] && $height <= $options[self::OPTION_HEIGHT]) {
                // nothing to do
                return null;
            }

            // resize image
            $this->_thumbnailer->resize($options[self::OPTION_WIDTH], $options[self::OPTION_HEIGHT]);

            // save the image
            if (isset($options[self::OPTION_OUTPUT_FORMAT])) {
                $this->_thumbnailer->save($destinationPath, $options[self::OPTION_OUTPUT_FORMAT]);
            } else {
                $this->_thumbnailer->save($destinationPath);
            }
        } catch (Exception $ex) {
            throw new SimpleGallery_Exception('Failed to resize image: ' . $ex->getMessage());
        }

        return true;
    }
}

/* EOF */