<?php
/**
 * Simple Gallery registry
 *
 * $Id: Registry.php 203 2011-02-18 17:46:16Z indy $
 *
 * $LastChangedBy: indy $
 *
 * $LastChangedDate: 2011-02-18 19:46:16 +0200 (Fri, 18 Feb 2011) $
 *
 * $Rev: 203 $
 *
 * @author Indiana Jones <indy2kro@yahoo.com>
 * @package SimpleGallery
 * @version 1.0
 * @copyright 2011 Simple Gallery
 */

/**
 * Simple Gallery registry
 */
class SimpleGallery_Registry
{
    /**
     * Registry object provides storage for shared objects.
     *
     * @var SimpleGallery_Registry
     */
    protected static $_registry = null;

    /**
     * Registry values
     * 
     * @var array
     */
    protected $_values = array();

    /**
     * Constructor - private because this is a Singleton class
     */
    private function __construct()
    {
        // nothing to do
    }

    /**
     * Retrieves the default registry instance.
     *
     * @return SimpleGallery_Registry
     */
    public static function getInstance()
    {
        if (is_null(self::$_registry)) {
            self::_init();
        }

        return self::$_registry;
    }

    /**
     * Set the default registry instance to a specified instance.
     *
     * @param SimpleGallery_Registry $registry An object instance of type SimpleGallery_Registry
     * @throws SimpleGallery_Exception if registry is already initialized.
     * @return void
     */
    public static function setInstance(SimpleGallery_Registry $registry)
    {
        if (!is_null(self::$_registry)) {
            throw new SimpleGallery_Exception('Registry is already initialized');
        }

        self::$_registry = $registry;
    }

    /**
     * Getter method
     *
     * @param string $index The index to get
     * @throws Exception
     * @return mixed
     */
    public static function get($index)
    {
        $instance = self::getInstance();

        if (!$instance->offsetExists($index)) {
            throw new SimpleGallery_Exception("No entry is registered for key '" . $index . "'");
        }

        return $instance->offsetGet($index);
    }

    /**
     * Setter method
     *
     * @param string $index The index to set
     * @param mixed $value The object to store
     * @return void
     */
    public static function set($index, $value)
    {
        $instance = self::getInstance();
        $instance->offsetSet($index, $value);
    }

    /**
     * Returns TRUE if the $index is a named value in the registry,
     * or FALSE if $index was not found in the registry.
     *
     * @param  string $index The index to check
     * @return boolean
     */
    public static function isRegistered($index)
    {
        if (self::$_registry === null) {
            return false;
        }
        return self::$_registry->offsetExists($index);
    }

    /**
     * Check if an offset exists
     *
     * @param string $index The index to check
     * @returns boolean
     */
    public function offsetExists($index)
    {
        return array_key_exists($index, $this->_values);
    }

    /**
     * Set offset value
     *
     * @param string $index The index to set
     * @param mixed $value The value to store
     * @return void
     */
    public function offsetSet($index, $value)
    {
        $this->_values[$index] = $value;
    }

    /**
     * Get offset value
     *
     * @param string $index The index to get
     * @return mixed
     */
    public function offsetGet($index)
    {
        return $this->_values[$index];
    }

    /**
     * Initialize the default registry instance.
     *
     * @return void
     */
    protected static function _init()
    {
        self::setInstance(new SimpleGallery_Registry());
    }
}

/* EOF */